Locale

Struct Locale 

pub struct Locale { /* private fields */ }

Implementations

Source

impl Locale

pub fn new(client: &Client) -> Self

pub fn get(&self) -> Result<Locale, AppwriteException>

Get the current user location based on IP. Returns an object with user country code, country name, continent name, continent code, ip address and suggested currency. You can use the locale header to get the data in a supported language.

(IP Geolocation by DB-IP)

pub fn get_continents(&self) -> Result<ContinentList, AppwriteException>

List of all continents. You can use the locale header to get the data in a supported language.

pub fn get_countries(&self) -> Result<CountryList, AppwriteException>

List of all countries. You can use the locale header to get the data in a supported language.

pub fn get_countries_eu(&self) -> Result<CountryList, AppwriteException>

List of all countries that are currently members of the EU. You can use the locale header to get the data in a supported language.

pub fn get_countries_phones(&self) -> Result<PhoneList, AppwriteException>

List of all countries phone codes. You can use the locale header to get the data in a supported language.

pub fn get_currencies(&self) -> Result<CurrencyList, AppwriteException>

List of all currencies, including currency symbol, name, plural, and decimal digits for all major and minor currencies. You can use the locale header to get the data in a supported language.

pub fn get_languages(&self) -> Result<LanguageList, AppwriteException>

List of all languages classified by ISO 639-1 including 2-letter code, name in English, and name in the respective language.