Teams

Struct Teams 

pub struct Teams { /* private fields */ }

Implementations

Source

impl Teams

pub fn new(client: &Client) -> Self

pub fn list( &self, search: Option<&str>, limit: Option<i64>, offset: Option<i64>, cursor: Option<&str>, cursor_direction: Option<&str>, order_type: Option<&str>, ) -> Result<TeamList, AppwriteException>

Get a list of all the teams in which the current user is a member. You can use the parameters to filter your results.

In admin mode, this endpoint returns a list of all the teams in the current project. Learn more about different API modes.

pub fn create( &self, team_id: &str, name: &str, roles: Option<&[&str]>, ) -> Result<Team, AppwriteException>

Create a new team. The user who creates the team will automatically be assigned as the owner of the team. Only the users with the owner role can invite new members, add new owners and delete or update the team.

pub fn get(&self, team_id: &str) -> Result<Team, AppwriteException>

Get a team by its ID. All team members have read access for this resource.

pub fn update( &self, team_id: &str, name: &str, ) -> Result<Team, AppwriteException>

Update a team using its ID. Only members with the owner role can update the team.

pub fn delete(&self, team_id: &str) -> Result<Value, AppwriteException>

Delete a team using its ID. Only team members with the owner role can delete the team.

pub fn get_memberships( &self, team_id: &str, search: Option<&str>, limit: Option<i64>, offset: Option<i64>, cursor: Option<&str>, cursor_direction: Option<&str>, order_type: Option<&str>, ) -> Result<MembershipList, AppwriteException>

Use this endpoint to list a team’s members using the team’s ID. All team members have read access to this endpoint.

pub fn create_membership( &self, team_id: &str, email: &str, roles: &[&str], url: &str, name: Option<&str>, ) -> Result<Membership, AppwriteException>

Invite a new member to join your team. If initiated from the client SDK, an email with a link to join the team will be sent to the member’s email address and an account will be created for them should they not be signed up already. If initiated from server-side SDKs, the new member will automatically be added to the team.

Use the ‘url’ parameter to redirect the user from the invitation email back to your app. When the user is redirected, use the Update Team Membership Status endpoint to allow the user to accept the invitation to the team.

Please note that to avoid a Redirect Attack the only valid redirect URL’s are the once from domains you have set when adding your platforms in the console interface.

pub fn get_membership( &self, team_id: &str, membership_id: &str, ) -> Result<MembershipList, AppwriteException>

Get a team member by the membership unique id. All team members have read access for this resource.

pub fn update_membership_roles( &self, team_id: &str, membership_id: &str, roles: &[&str], ) -> Result<Membership, AppwriteException>

Modify the roles of a team member. Only team members with the owner role have access to this endpoint. Learn more about roles and permissions.

pub fn delete_membership( &self, team_id: &str, membership_id: &str, ) -> Result<Value, AppwriteException>

This endpoint allows a user to leave a team or for a team owner to delete the membership of any other team member. You can also use this endpoint to delete a user membership even if it is not accepted.

pub fn update_membership_status( &self, team_id: &str, membership_id: &str, user_id: &str, secret: &str, ) -> Result<Membership, AppwriteException>

Use this endpoint to allow a user to accept an invitation to join a team after being redirected back to your app from the invitation email received by the user.

If the request is successful, a session for the user is automatically created.