pub struct Health { /* private fields */ }Implementations
Sourceimpl Health
impl Health
pub fn new(client: &Client) -> Self
Sourcepub fn get(&self) -> Result<HealthStatus, AppwriteException>
pub fn get(&self) -> Result<HealthStatus, AppwriteException>
Check the Appwrite HTTP server is up and responsive.
Sourcepub fn get_antivirus(&self) -> Result<HealthAntivirus, AppwriteException>
pub fn get_antivirus(&self) -> Result<HealthAntivirus, AppwriteException>
Check the Appwrite Antivirus server is up and connection is successful.
Sourcepub fn get_cache(&self) -> Result<HealthStatus, AppwriteException>
pub fn get_cache(&self) -> Result<HealthStatus, AppwriteException>
Check the Appwrite in-memory cache server is up and connection is successful.
Sourcepub fn get_db(&self) -> Result<HealthStatus, AppwriteException>
pub fn get_db(&self) -> Result<HealthStatus, AppwriteException>
Check the Appwrite database server is up and connection is successful.
Sourcepub fn get_queue_certificates(&self) -> Result<HealthQueue, AppwriteException>
pub fn get_queue_certificates(&self) -> Result<HealthQueue, AppwriteException>
Get the number of certificates that are waiting to be issued against Letsencrypt in the Appwrite internal queue server.
pub fn get_queue_functions(&self) -> Result<HealthQueue, AppwriteException>
Sourcepub fn get_queue_logs(&self) -> Result<HealthQueue, AppwriteException>
pub fn get_queue_logs(&self) -> Result<HealthQueue, AppwriteException>
Get the number of logs that are waiting to be processed in the Appwrite internal queue server.
Sourcepub fn get_queue_usage(&self) -> Result<HealthQueue, AppwriteException>
pub fn get_queue_usage(&self) -> Result<HealthQueue, AppwriteException>
Get the number of usage stats that are waiting to be processed in the Appwrite internal queue server.
Sourcepub fn get_queue_webhooks(&self) -> Result<HealthQueue, AppwriteException>
pub fn get_queue_webhooks(&self) -> Result<HealthQueue, AppwriteException>
Get the number of webhooks that are waiting to be processed in the Appwrite internal queue server.
Sourcepub fn get_storage_local(&self) -> Result<HealthStatus, AppwriteException>
pub fn get_storage_local(&self) -> Result<HealthStatus, AppwriteException>
Check the Appwrite local storage device is up and connection is successful.
Sourcepub fn get_time(&self) -> Result<HealthTime, AppwriteException>
pub fn get_time(&self) -> Result<HealthTime, AppwriteException>
Check the Appwrite server time is synced with Google remote NTP server. We use this technology to smoothly handle leap seconds with no disruptive events. The Network Time Protocol (NTP) is used by hundreds of millions of computers and devices to synchronize their clocks over the Internet. If your computer sets its own clock, it likely uses NTP.