pub struct Storage { /* private fields */ }Implementations
Sourceimpl Storage
impl Storage
pub fn new(client: &Client) -> Self
Sourcepub fn list_buckets(
&self,
search: Option<&str>,
limit: Option<i64>,
offset: Option<i64>,
cursor: Option<&str>,
cursor_direction: Option<&str>,
order_type: Option<&str>,
) -> Result<BucketList, AppwriteException>
pub fn list_buckets( &self, search: Option<&str>, limit: Option<i64>, offset: Option<i64>, cursor: Option<&str>, cursor_direction: Option<&str>, order_type: Option<&str>, ) -> Result<BucketList, AppwriteException>
Get a list of all the storage buckets. You can use the query params to filter your results.
Sourcepub fn create_bucket(
&self,
bucket_id: &str,
name: &str,
permission: &str,
read: Option<&[&str]>,
write: Option<&[&str]>,
enabled: Option<bool>,
maximum_file_size: Option<i64>,
allowed_file_extensions: Option<&[&str]>,
encryption: Option<bool>,
antivirus: Option<bool>,
) -> Result<Bucket, AppwriteException>
pub fn create_bucket( &self, bucket_id: &str, name: &str, permission: &str, read: Option<&[&str]>, write: Option<&[&str]>, enabled: Option<bool>, maximum_file_size: Option<i64>, allowed_file_extensions: Option<&[&str]>, encryption: Option<bool>, antivirus: Option<bool>, ) -> Result<Bucket, AppwriteException>
Create a new storage bucket.
Sourcepub fn get_bucket(&self, bucket_id: &str) -> Result<Bucket, AppwriteException>
pub fn get_bucket(&self, bucket_id: &str) -> Result<Bucket, AppwriteException>
Get a storage bucket by its unique ID. This endpoint response returns a JSON object with the storage bucket metadata.
Sourcepub fn update_bucket(
&self,
bucket_id: &str,
name: &str,
permission: &str,
read: Option<&[&str]>,
write: Option<&[&str]>,
enabled: Option<bool>,
maximum_file_size: Option<i64>,
allowed_file_extensions: Option<&[&str]>,
encryption: Option<bool>,
antivirus: Option<bool>,
) -> Result<Bucket, AppwriteException>
pub fn update_bucket( &self, bucket_id: &str, name: &str, permission: &str, read: Option<&[&str]>, write: Option<&[&str]>, enabled: Option<bool>, maximum_file_size: Option<i64>, allowed_file_extensions: Option<&[&str]>, encryption: Option<bool>, antivirus: Option<bool>, ) -> Result<Bucket, AppwriteException>
Update a storage bucket by its unique ID.
Sourcepub fn delete_bucket(&self, bucket_id: &str) -> Result<Value, AppwriteException>
pub fn delete_bucket(&self, bucket_id: &str) -> Result<Value, AppwriteException>
Delete a storage bucket by its unique ID.
Sourcepub fn list_files(
&self,
bucket_id: &str,
search: Option<&str>,
limit: Option<i64>,
offset: Option<i64>,
cursor: Option<&str>,
cursor_direction: Option<&str>,
order_type: Option<&str>,
) -> Result<FileList, AppwriteException>
pub fn list_files( &self, bucket_id: &str, search: Option<&str>, limit: Option<i64>, offset: Option<i64>, cursor: Option<&str>, cursor_direction: Option<&str>, order_type: Option<&str>, ) -> Result<FileList, AppwriteException>
Get a list of all the user files. You can use the query params to filter your results. On admin mode, this endpoint will return a list of all of the project’s files. Learn more about different API modes.
Sourcepub fn create_file(
&self,
bucket_id: &str,
file_id: &str,
file: PathBuf,
read: Option<&[&str]>,
write: Option<&[&str]>,
) -> Result<File, AppwriteException>
pub fn create_file( &self, bucket_id: &str, file_id: &str, file: PathBuf, read: Option<&[&str]>, write: Option<&[&str]>, ) -> Result<File, AppwriteException>
Create a new file. Before using this route, you should create a new bucket resource using either a server integration API or directly from your Appwrite console.
Larger files should be uploaded using multiple requests with the
content-range
header to send a partial request with a maximum supported chunk of 5MB.
The content-range header values should always be in bytes.
When the first request is sent, the server will return the File object,
and the subsequent part request must include the file’s id in
x-appwrite-id header to allow the server to know that the partial upload
is for the existing file and not for a new one.
If you’re creating a new file using one of the Appwrite SDKs, all the chunking logic will be managed by the SDK internally.
Sourcepub fn get_file(
&self,
bucket_id: &str,
file_id: &str,
) -> Result<File, AppwriteException>
pub fn get_file( &self, bucket_id: &str, file_id: &str, ) -> Result<File, AppwriteException>
Get a file by its unique ID. This endpoint response returns a JSON object with the file metadata.
Sourcepub fn update_file(
&self,
bucket_id: &str,
file_id: &str,
read: Option<&[&str]>,
write: Option<&[&str]>,
) -> Result<File, AppwriteException>
pub fn update_file( &self, bucket_id: &str, file_id: &str, read: Option<&[&str]>, write: Option<&[&str]>, ) -> Result<File, AppwriteException>
Update a file by its unique ID. Only users with write permissions have access to update this resource.
Sourcepub fn delete_file(
&self,
bucket_id: &str,
file_id: &str,
) -> Result<Value, AppwriteException>
pub fn delete_file( &self, bucket_id: &str, file_id: &str, ) -> Result<Value, AppwriteException>
Delete a file by its unique ID. Only users with write permissions have access to delete this resource.
Sourcepub fn get_file_download(
&self,
bucket_id: &str,
file_id: &str,
) -> Result<Vec<u8>, AppwriteException>
pub fn get_file_download( &self, bucket_id: &str, file_id: &str, ) -> Result<Vec<u8>, AppwriteException>
Get a file content by its unique ID. The endpoint response return with a ‘Content-Disposition: attachment’ header that tells the browser to start downloading the file to user downloads directory.
Sourcepub fn get_file_preview(
&self,
bucket_id: &str,
file_id: &str,
width: Option<i64>,
height: Option<i64>,
gravity: Option<&str>,
quality: Option<i64>,
border_width: Option<i64>,
border_color: Option<&str>,
border_radius: Option<i64>,
opacity: Option<f64>,
rotation: Option<i64>,
background: Option<&str>,
output: Option<&str>,
) -> Result<Vec<u8>, AppwriteException>
pub fn get_file_preview( &self, bucket_id: &str, file_id: &str, width: Option<i64>, height: Option<i64>, gravity: Option<&str>, quality: Option<i64>, border_width: Option<i64>, border_color: Option<&str>, border_radius: Option<i64>, opacity: Option<f64>, rotation: Option<i64>, background: Option<&str>, output: Option<&str>, ) -> Result<Vec<u8>, AppwriteException>
Get a file preview image. Currently, this method supports preview for image files (jpg, png, and gif), other supported formats, like pdf, docs, slides, and spreadsheets, will return the file icon image. You can also pass query string arguments for cutting and resizing your preview image. Preview is supported only for image files smaller than 10MB.
Sourcepub fn get_file_view(
&self,
bucket_id: &str,
file_id: &str,
) -> Result<Vec<u8>, AppwriteException>
pub fn get_file_view( &self, bucket_id: &str, file_id: &str, ) -> Result<Vec<u8>, AppwriteException>
Get a file content by its unique ID. This endpoint is similar to the download method but returns with no ‘Content-Disposition: attachment’ header.